@@ -107,7 +107,7 @@ def takescreenshot(file,screenshotaddress,screenshotnum):
             screenshotstr='ffmpeg -ss '+str(firststep)+' -i "'+file+'" -f image2 -y "'+os.path.join(screenshotaddress,str(i+1)+'.jpg')+'"'
         else:
             screenshotstr='ffmpeg -ss '+str(firststep)+' -i "'+file+'" -f image2 -y "'+os.path.join(screenshotaddress,str(i+1)+'.jpg')+'" &> /dev/null'
-        print(screenshotstr)
+        #print(screenshotstr)
         os.system(screenshotstr)
     logger.info('截图完毕')
 
